var react = require('react');

function getWindowSize() {
  const width = typeof window !== "undefined" ? window.innerWidth : 0;
  const height = typeof window !== "undefined" ? window.innerHeight : 0;
  return {
    width,
    height
  };
}

function useWindowSize() {
  const [size, setSize] = react.useState(getWindowSize());

  const handleResize = () => setSize(getWindowSize());

  react.useLayoutEffect(() => {
    window.addEventListener("resize", handleResize);
    return () => {
      window.removeEventListener("resize", handleResize);
    };
  }, []);
  return size;
}

exports.useWindowSize = useWindowSize;
